@@ -7,11 +7,11 @@ import sys
 import types
 import typing
 import typing_extensions
-from typing import *  # type: ignore
+from typing import *
 
 from .i_hate_circular_imports import parameterize
 from ..classes import safe_is_subclass
-from ..types import Type_, GenericAliases
+from ..types import Type_, GenericAliases, TypeParameter
 from ..errors import *
 
 __all__ = [
@@ -112,7 +112,7 @@ def _resolve_dotted_names(
 
             result.append(value)
 
-        return type(names)(result)  # type: ignore
+        return type(names)(result)
 
 
 # NOTE: The following function implementations work in python 3.5.
@@ -136,6 +136,7 @@ _VARIADIC_GENERICS = {
 VARIADIC_GENERICS: Set[object] = {
     getattr(typing, attr) for attr in _VARIADIC_GENERICS if hasattr(typing, attr)
 }
+VARIADIC_GENERICS.add(typing_extensions.Literal)
 
 if sys.version_info >= (3, 9):
     VARIADIC_GENERICS.add(tuple)
@@ -303,24 +304,9 @@ def _get_type_parameters(type_):
 
         return type_.__parameters__  # type: ignore
 
-    if isinstance(type_, PARAMETERIZED_GENERIC_META):
-        if sys.version_info < (3, 7):
-            # Callable is an outlier that never has __orig_bases__
-            if not type_.__orig_bases__ and type_._gorg is not Callable:
-                return None
-
+    if isinstance(type_, PARAMETERIZED_GENERIC_META):  # type: ignore
         return type_.__parameters__
 
-    if sys.version_info < (3, 7) and hasattr(typing, "_Union"):
-        if isinstance(type_, _Union):
-            return type_.__parameters__
-
-    # Special case: ClassVar can only be parameterized once in older
-    # versions
-    if sys.version_info < (3, 7) and hasattr(typing, "_ClassVar"):
-        if isinstance(type_, _ClassVar):
-            return ()
-
     return None
 
 
@@ -332,47 +318,33 @@ PARAMLESS_SUBSCRIPTABLES = {
 
 
 def _is_generic_base_class(cls):
-    if isinstance(cls, (CallableMeta, _Union)):
+    if isinstance(cls, (CallableMeta, _Union)):  # type: ignore
         return cls.__args__ is None
 
-    if isinstance(cls, GenericMeta):
+    if isinstance(cls, GenericMeta):  # type: ignore
         return cls.__args__ is None and bool(cls.__parameters__)
 
-    if type(cls) is _ClassVar:
+    if type(cls) is _ClassVar:  # type: ignore
         return cls.__type__ is None
 
     return cls in {Union, Optional, ClassVar}
 
 
 def _is_parameterized_generic(cls):
-    if isinstance(cls, (GenericMeta, _Union)):
+    if isinstance(cls, (GenericMeta, _Union)):  # type: ignore
         return cls.__args__ is not None
 
-    if type(cls) is _ClassVar:
+    if type(cls) is _ClassVar:  # type: ignore
         return cls.__type__ is not None
 
     return False
 
 
-def _is_typing_type(cls):
-    if not isinstance(cls, (TypingMeta, _TypingBase)):
-        return False
-
-    if _is_parameterized_generic(cls):
-        return True
-
-    return cls.__module__ == "typing"
-
-
-def _get_generic_base_class(cls):
+def _get_generic_base_class(cls):  # type: ignore
     return cls.__origin__
 
 
-def _to_python(cls):
-    return getattr(cls, "__extra__", None)
-
-
-def _get_name(cls):
+def _get_name(cls):  # type: ignore
     try:
         return cls.__name__
     except AttributeError:
@@ -382,67 +354,75 @@ def _get_name(cls):
     return name
 
 
-if sys.version_info >= (3, 7):
-    SPECIAL_GENERICS = {Optional, Union, ClassVar, Callable}
+SPECIAL_GENERICS = {
+    Optional,
+    Union,
+    ClassVar,
+    Callable,
+    Literal,
+    typing_extensions.Literal,
+    Final,
+    typing_extensions.Final,
+}
 
-    if hasattr(typing, "Literal"):  # python 3.8+
-        SPECIAL_GENERICS.add(Literal)
 
-    if hasattr(typing, "Final"):  # python 3.8+
-        SPECIAL_GENERICS.add(Final)
+def _is_parameterized_generic(cls):
+    if isinstance(cls, GenericAliases):
+        return not cls._special
 
-    def _is_parameterized_generic(cls):
-        if isinstance(cls, GenericAliases):
-            return not cls._special
+    return False
 
+
+def _is_generic_base_class(cls):
+    if isinstance(cls, GenericAliases):
+        # The _special attribute was removed in 3.9
+        if not cls._special:
+            return False
+    elif not isinstance(cls, (type, _SpecialForm)):  # type: ignore
         return False
 
-    def _is_generic_base_class(cls):
-        if isinstance(cls, GenericAliases):
-            # The _special attribute was removed in 3.9
-            if not cls._special:
-                return False
-        elif not isinstance(cls, (type, _SpecialForm)):
-            return False
+    return is_generic(cls)
 
-        return is_generic(cls)
 
-    def _is_typing_type(cls):
-        if isinstance(cls, GenericAliases):
+def _is_typing_type(cls):
+    if isinstance(cls, GenericAliases):
+        return True
+
+    if sys.version_info >= (3, 10):
+        if cls is types.UnionType or isinstance(cls, types.UnionType):
             return True
 
-        if sys.version_info >= (3, 10):
-            if cls is types.UnionType or isinstance(cls, types.UnionType):
-                return True
+    try:
+        module = cls.__module__
+    except AttributeError:
+        return False
 
-        try:
-            module = cls.__module__
-        except AttributeError:
-            return False
+    return module in ("typing", "typing_extensions")
 
-        return module == "typing"
 
-    def _get_generic_base_class(cls):
-        if cls._name is not None:
-            return getattr(typing, cls._name)
+def _get_generic_base_class(cls):  # type: ignore
+    if cls._name is not None:
+        return getattr(typing, cls._name)
 
-        return cls.__origin__
+    return cls.__origin__
 
-    def _to_python(cls):
-        return getattr(cls, "__origin__", None)
 
-    def _get_name(cls):
-        try:
-            return cls.__name__
-        except AttributeError:
-            return cls._name
+def _to_python(cls):  # NOT an unused function! IDE is wrong!
+    return getattr(cls, "__origin__", None)
+
+
+def _get_name(cls):
+    try:
+        return cls.__name__
+    except AttributeError:
+        return cls._name
 
 
 if sys.version_info >= (3, 9):
 
     def _is_generic_base_class(cls):
         if safe_is_subclass(cls, Generic):
-            return bool(cls.__parameters__)
+            return bool(cls.__parameters__)  # type: ignore
 
         return False
 
@@ -457,7 +437,7 @@ if sys.version_info >= (3, 9):
             if getattr(cls, "_name", None) is not None:
                 return getattr(typing, cls._name)
 
-            if isinstance(cls, typing._AnnotatedAlias):
+            if isinstance(cls, typing._AnnotatedAlias):  # type: ignore
                 return Annotated
 
             try:
@@ -473,13 +453,13 @@ if sys.version_info >= (3, 9):
 
 if hasattr(typing, "get_args"):  # python 3.8+
 
-    def _get_type_args(cls):
+    def _get_type_args(cls):  # type: ignore
         return get_args(cls)
 
 else:
     if hasattr(Union, "_subs_tree"):  # python <3.7
 
-        def _get_base_and_args(cls):
+        def _get_base_and_args(cls):  # type: ignore
             # In older python versions, generics only store the
             # last pair of arguments. For instance,
             #    >>> Tuple[List[T]][int].__args__
@@ -874,7 +854,7 @@ def get_type_arguments(type_: Type_) -> Tuple[object, ...]:
 
     try:
         if isinstance(type_, dataclasses.InitVar):
-            return (type_.type,)  # type: ignore
+            return (type_.type,)
     except AttributeError:
         pass
 
@@ -895,7 +875,7 @@ def get_type_arguments(type_: Type_) -> Tuple[object, ...]:
     return args
 
 
-def get_type_parameters(type_: Type_) -> Tuple[TypeVar, ...]:
+def get_type_parameters(type_: Type_) -> Tuple[TypeParameter, ...]:
     """
     Returns the TypeVars of a generic type.
 
@@ -954,7 +934,7 @@ def get_type_parameters(type_: Type_) -> Tuple[TypeVar, ...]:
     except (KeyError, TypeError):
         pass
     else:
-        params = ordered_set.OrderedSet()  # type: ignore
+        params = ordered_set.OrderedSet(())
 
         for base, *typevars in bases:
             params.update(typevars)
@@ -1058,12 +1038,12 @@ def get_type_argument_for(
         for base in get_parent_types(cls):
             if is_parameterized_generic(base):
                 cls = get_generic_base_class(base)
-                if not safe_is_subclass(cls, base_type):
+                if not safe_is_subclass(cls, base_type):  # type: ignore
                     continue
 
                 args = get_type_arguments(base)
                 break
-            elif safe_is_subclass(base, base_type):
+            elif safe_is_subclass(base, base_type):  # type: ignore
                 cls = base
                 args = ()
                 break
@@ -1092,7 +1072,7 @@ def get_type_argument_for(
             if assume_any:
                 return Any
 
-            raise TypeVarNotSet(type_var, base_type, type_)
+            raise TypeVarNotSet(type_var, base_type, type_)  # type: ignore
 
         if not isinstance(arg, TypeVar):
             return arg
@@ -1100,7 +1080,7 @@ def get_type_argument_for(
         current_var = arg
 
     if not allow_typevar:
-        raise NoConcreteTypeForTypeVar(type_var, base_type, type_, current_var)
+        raise NoConcreteTypeForTypeVar(type_var, base_type, type_, current_var)  # type: ignore
 
     return current_var
 
